/***************************************************************************
 *   Copyright (C) 2009 by QEVEN Team                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 **************************************************************************/

#ifndef UTILSVIDEO_ANALYZER_H
#define UTILSVIDEO_ANALYZER_H

#include <QString>
#include <QProcess>
#include <stdexcept>

namespace utils {

   /**
     * @class Video_Analyzer
     * @brief Analiza un video de entrada y obtiene todos sus datos.
     *
     * Clase que analiza un video de entrada y obtiene todos sus datos
     * como: Bitrate de video, bitrate de audio, relacion de aspecto,
     * duracion, nombre y directorio donde se encuentra.
     * Utiliza el mplayer para obtener toda la informacion, que luego es
     * filtrada a través de expresiones regulares de QT.
     */
   class Video_Analyzer
   {
        public:

      Video_Analyzer( QString video_file, QString bmplayer );
      ~Video_Analyzer();
      QString get_Video_Name();
      QString get_Video_Directory(); //returns video directory
      QString get_Video_Full_Path();//return the path to the video, including filename
      int get_Video_Bitrate();
      int get_Audio_Bitrate();
      int get_Duration();
      int get_Video_Width();
      int get_Video_Height();
      int get_aid();
      float get_Fps();
      float get_Video_Aspect();
      void read_Video( QString video_file );



        private:
      QProcess* m_read_video_process; //proceso para ejecutar el mplayer.
      QString m_video_info;
      QString m_video_name; // nombre de archivo
      QString m_video_directory; //ruta al archivo
      QString m_video_full_path; //ruta al archivo incluyendo su nombre y extension
      int m_video_bitrate;
      int m_audio_bitrate;
      int m_duration;
      int m_video_with;
      int m_video_height;
      float m_fps;
      float m_video_aspect;
      int m_aid;

      QString MPlayer;
   };
}

#endif
