/***************************************************************************
 *   Copyright (C) 2009 by QEVEN Team                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 **************************************************************************/

#ifndef VIDEOVIDEO_ITEM_H
#define VIDEOVIDEO_ITEM_H

#include <QString>
#include <QFileInfo>
#include <QStringList>
#include "enum.h"

namespace video {

   /**
    *@class Video_Item
    * @brief Contiene todo los referente a un elemento de video.
    *
    * Esta clase maneja todos los datos de un elemento de video,
    * como Titulo, bitrate de video, de audio,relacion de aspecto,
    * subtitulos, fuente de los subtitulos, etc.
    * Además retorna el comando específico que se le pasa al MEncoder
    * para convertir.
    */
   class Video_Item
   {
        public:
      Video_Item();
      Video_Item( QString filename,
                  QString filepath,
                  int video_bitrate,
                  int audio_bitrate,
                  int duration,
                  e_video_format format );
      Video_Item( QString filename,
                  QString filepath,
                  int video_bitrate,
                  int audio_bitrate,
                  int duration,
                  e_video_format format,
                  QString aspect,
                  bool has_Subs,
                  QString subsPath,
                  QString subsFont,
                  int subsScale );
      ~Video_Item();

      void Update(int vbitrate, int abitrate, QString aspect,
                  QString sFont, int sScale,
                  float fps, int resolution, int w, int h);

      void set_Video_Filename( QString );
      void set_Video_Path ( QString );
      void set_Video_Bitrate( int );
      void set_Audio_Bitrate( int );
      void set_Video_Duration( int );
      void set_Subtitles_Font( QString );
      void set_Subtitles_File( QString );
      void set_Subtitles_Scale( int );
      void set_Video_Aspect( QString );
      void set_Has_Subtitles( bool );
      void set_Format( e_video_format format );
      void set_Video_Width(int);
      void set_Video_Height(int);
      void set_Fps(float);
      void set_Video_Width_Original(int);
      void set_Video_Height_Original(int);
      void set_Video_Resolution(int);
      void set_aid(int); // id del canal de audio

      QString get_Video_Name();
      QString get_Video_Output_Name();
      QString get_Video_Path();
      int get_Video_Bitrate();
      int get_Audio_Bitrate();
      int get_Video_Duration();
      float get_Video_Size();
      int get_Subtitles_Scale();
      QString get_Subtitles_Font();
      QString get_Subtitles_File();
      QString get_Video_Aspect();
      bool has_Subtitles();
      e_video_format get_Format();
      int get_Video_Width();
      int get_Video_Height();
      float get_Fps();
      int get_Video_Resolution();
      int get_Video_Width_Original();
      int get_Video_Height_Original();
      int get_aid();

      QString get_Command(); // construye el comando que ejecutar
      QString toXML();

        private:
      QString m_video_filename;
      QString m_video_path;

      QString m_subtitles;
      QString m_subtitles_font;
      int m_subtitles_scale;
      bool m_has_Subtitles;

      QString m_video_aspect;

      QString m_command;

      int m_video_bitrate;
      int m_audio_bitrate;
      int m_video_duration;
      float m_video_size;

      e_video_format m_format;

      int m_resolution;
      int m_video_width;
      int m_video_height;
      int m_video_width_original;
      int m_video_height_original;
      int m_aid;

      float m_fps;


   };

}

#endif
