/***************************************************************************
 *   Copyright (C) 2009 by QEVEN Team                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 **************************************************************************/

#include "converter_gui.h"
#include <QSettings>
#include <QDir>
#include <QCloseEvent>
// for std::exception only
#include <stdexcept>
using namespace std;

Converter_GUI::Converter_GUI( QWidget* parent,
                              Qt::WFlags fl) :
QWidget(parent, fl),
Ui::Converter_Form()
{
   setupUi(this);
   m_total_jobs = 0;
   m_current_job = 0;
   m_current_preview = 0;
   m_output_directory = "";
   m_percent = 0;
   cancelled = false;
   MEncoder = "";
   MPlayer = "";
   m_time_remaining = "Calculando...";
   m_videos_to_convert = new QList< Video_Item* >();
   converter = new Video_Converter;
   m_video_preview = new Mplayer_Preview(previewWidget);
   m_video_preview->setFixedSize( 440, 250 );


   timer = new QTimer;
   timer->setSingleShot( true );
   connect( converter, SIGNAL( Percent_Completed( const int& ) ),
            this, SLOT( Read_Percent( const int& ) ) );
   connect( converter, SIGNAL( Time_Remaining (const QString& ) ),
            this, SLOT( Read_Time_Remaining( const QString& ) ) );
   connect( converter, SIGNAL( Process_Has_Finished() ), this,
            SLOT( Convert() ) );
   connect( cancelButton, SIGNAL( clicked() ), this,
            SLOT( Cancel() ) );
   connect( timer, SIGNAL( timeout() ),
            this, SLOT( Start_Preview() ) );

   readSettings();
}

Converter_GUI::~Converter_GUI()
{
   delete m_videos_to_convert;
   delete converter;
   delete timer;
   delete m_video_preview;

}

void Converter_GUI::Initialize( QList<Video_Item*>* video_list,
                                QString output_directory, bool ppreview_option )
{
   cancelled=false;
#ifdef Q_OS_WIN32
   QStringList path_aux = output_directory.split( "/" );
   output_directory= path_aux.join( "\\" ).append( "\\" );
#endif
   converter->set_Output_Dir( output_directory );
   m_videos_to_convert = video_list;
   m_total_jobs = m_videos_to_convert->count();
   m_current_job = 0;
   m_output_directory = output_directory;
   outputDirEdit->setText( m_output_directory );
   preview_option = ppreview_option;

   //Para mostrar mensaje si no seleccionó Preview Video. on 2008-11-18 12:23:58
   if(preview_option)
   {
      Ui_Converter_Form::preview_message->setHidden(true);
   }
   else
   {
      Ui_Converter_Form::preview_message->setHidden(false);
   }
   Convert();
}

void Converter_GUI::Read_Percent( const int& percent )
{
   m_percent = percent;

   Update_GUI();
}

void Converter_GUI::Read_Time_Remaining( const QString& time )
{
   m_time_remaining = time;
   Update_GUI();
}

void Converter_GUI::Convert()
{
   if( m_video_preview->is_running_mplayer() )
   {
      m_video_preview->quit_mplayer();
   }

   m_percent = 0;
   m_time_remaining = "Calculando...";

   if( cancelled == false )
   {
      timer->setInterval( 5000 ); // esperar 5 segundos para comenzar el preview
      timer->start(); //iniciar el temporizador

      if ( m_current_job < m_total_jobs )
      {
         converter->convert( m_videos_to_convert->value( m_current_job )->get_Video_Output_Name(),
                             m_videos_to_convert->value(m_current_job)->get_Command(),MEncoder );
         m_current_job++;

         Update_GUI();
         jobsLabel->setText(tr("%1 de %2").arg(m_current_job).arg(m_total_jobs));
      }
      else
      {
         Conversion_Finished();
      }
   }
}

void Converter_GUI::Start_Preview()
{
   if( m_video_preview->is_running_mplayer() )
   {
      m_video_preview->quit_mplayer();
   }
   //Para que no abra el mplayer, si no se seleccionó Preview Video.2008-11-18 12:28:37
   if(preview_option)
   {
      m_video_preview->preview_video( converter->get_Output_File() ,MPlayer.toStdString());
   }
}

void Converter_GUI::Conversion_Finished()
{
   if( m_video_preview->is_running_mplayer() )
   {
      m_video_preview->quit_mplayer();
   }

   timer->stop();

   // si esta minimizado en el system try entonces mostramos el mensaje ademas
   if( true == this->isHidden() )
   {
      this->tryIcon->showMessage(tr("Terminado"), tr("El proceso de conversion ha finalizado"));
   }

   QMessageBox::information( this,
                             tr("Terminado!!!"),
                             tr("El proceso de conversion ha finalizado."),
                             QMessageBox::Ok );

   emit Finished();
   this->hide();
}

void Converter_GUI::Update_GUI()
{


   progressBar->setValue( m_percent );

   if (m_time_remaining == "0min" )
   {
      timeLabel->setText(tr("Menos de 1 min"));
   }
   else
   {
      timeLabel->setText(m_time_remaining);
   }
}

void Converter_GUI::Cancel()
{
   cancelled=true;
   m_video_preview->quit_mplayer();
   timer->stop();
   converter->Cancel_Process();


   emit Cancelled();

   this->hide();
}


void Converter_GUI::SetProgramDir(QString mEncoder, QString mPlayer)
{
   // set the correct OS-like file path
#ifdef Q_OS_WIN32
   this->MEncoder = "\"" + mEncoder + "\"";
   this->MPlayer = "\"" + mPlayer + "\"";
#endif
#ifdef Q_OS_LINUX
   this->MEncoder = mEncoder.replace( " ", "\\ " );
   this->MPlayer = mPlayer.replace( " ", "\\ " );
#endif
}

// si el usuario cierra la ventana
// se minimiza al tryIcon
void Converter_GUI::closeEvent(QCloseEvent *event)
{
   /*  cancelled=true;
    m_video_preview->quit_mplayer();
    timer->stop();
    converter->Cancel_Process();


    emit Cancelled();


    writeSettings();
       this->close();*/
   event->ignore();
   this->hide();

   // mostramos la advertencia en el tryIcon
   if( true == this->firstTrayMsg )
   {
      this->firstTrayMsg = false;
      this->tryIcon->showMessage(tr("Info"), tr("La aplicacion se ha minimizado"));
   }
}


void Converter_GUI::readSettings()
{
#ifdef Q_OS_LINUX
   QSettings settings(  QDir::homePath() + "/.QEVEN/config.ini", QSettings::IniFormat );
#else
   QSettings ini(QSettings::IniFormat,QSettings::UserScope,
                 QCoreApplication::organizationName(),
                 QCoreApplication::applicationName());
   QString dir = QFileInfo(ini.fileName()).absolutePath()+"/QEVEN/config.ini";
   QSettings settings( dir,  QSettings::IniFormat );
#endif
   QPoint pos = settings.value( "CW_Position", QPoint( 0, 0 ) ).toPoint();
   QSize size = settings.value( "CW_Size", QSize( 463, 404 ) ).toSize();
   move( pos );
   resize( size );
}



void Converter_GUI::writeSettings()
{
#ifdef Q_OS_LINUX
   QSettings settings(  QDir::homePath() + "/.QEVEN/config.ini", QSettings::IniFormat );
#else
   QSettings ini(QSettings::IniFormat,QSettings::UserScope,
                 QCoreApplication::organizationName(),
                 QCoreApplication::applicationName());
   QString dir = QFileInfo(ini.fileName()).absolutePath()+"/QEVEN/config.ini";
   QSettings settings( dir,  QSettings::IniFormat );
#endif
   settings.setValue( "CW_Position", pos() );
   settings.setValue( "CW_Size", size() );
}

/*
   adicione el tryIcon de la app principal en esta ventana tambien
   para manipular mensajes de x-tipo
*/
void Converter_GUI::set_try_icon( QSystemTrayIcon* tryIcon, bool firstUseFlag )
{
   if( 0 != tryIcon )
   {
      this->tryIcon = tryIcon;
      this->firstTrayMsg = firstUseFlag;
   }
   else
   {
      throw new runtime_error( "Assertion failed! Null object received" );
   }
}
