/***************************************************************************
 *   Copyright (C) 2009 by QEVEN Team                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 **************************************************************************/

#ifndef CONVERTER_GUI_H
#define CONVERTER_GUI_H

#include <QWidget>
#include "ui_Converter_gui.h"
#include "video_item.h"
#include <QList>
#include "video_converter.h"
#include "mplayer_preview.h"
#include <QMessageBox>
#include <QTimer>
#include <QSystemTrayIcon>

class QCloseEvent;

using namespace video;
using namespace utils;

/**
 * @class Converter_GUI
 * Clase encargada de visualizar el proceso de
 * conversion. Muestra una previsualización del video
 * que se encuentre convirtiendo, asi como el porciento
 * completado y el tiempo restante para concluir la operación actual
 */
class Converter_GUI : public QWidget,
private Ui::Converter_Form
{
   Q_OBJECT

    public:
   Converter_GUI( QWidget* parent = 0, Qt::WFlags fl = 0 );
   ~Converter_GUI();

   void Update_GUI(); // actualiza la interfaz, barras de progreso, etc, durante la conversion
   void Conversion_Finished();
   //Adicionada opción del preview. on 2008-11-18 12:23:58
   void Initialize( QList<Video_Item*>*, QString output_directory, bool preview_option ); // Inicializa el Convertidor, recibe la lista de videos y el dir de salida
   void SetProgramDir(QString MEncoder, QString MPlayer);
   void closeEvent(QCloseEvent *event);
   void set_try_icon( QSystemTrayIcon*, bool );

    public slots:
   void Read_Percent( const int& percent );
   void Read_Time_Remaining( const QString& time );
   void Start_Preview();
   void Convert();
   void Cancel();

    private:
   void readSettings();
   void writeSettings();

   Mplayer_Preview* m_video_preview;
   QTimer* timer;
   QList<Video_Item*>* m_videos_to_convert;
   QString m_output_directory;
   Video_Converter* converter;
   int m_total_jobs;
   int m_current_job;
   int m_current_preview;
   int m_percent;
   QString m_time_remaining;
   bool cancelled;
   //Adicionado atributo para seleccionar si se quiere el preview o no. on 2008-11-18 12:23:58
   bool preview_option;
   QString MEncoder;
   QString MPlayer;
   QSystemTrayIcon* tryIcon;
   // first use flag
   bool firstTrayMsg;

    signals:
   void Cancelled();
   void Finished();
};

#endif

